===========
wagtail-2fa
===========


Status
======
.. image:: https://travis-ci.org/LabD/wagtail-2fa.svg?branch=master
    :target: https://travis-ci.org/LabD/wagtail-2fa

.. image:: http://codecov.io/github/LabD/wagtail-2fa/coverage.svg?branch=master
    :target: http://codecov.io/github/LabD/wagtail-2fa?branch=master

.. image:: https://img.shields.io/pypi/v/wagtail-2fa.svg
    :target: https://pypi.python.org/pypi/wagtail-2fa/


Installation
============

.. code-block:: shell

   pip install wagtail-2fa
